@@ -31,6 +31,7 @@ from smartparams.exceptions import (
     MissingDumpPath,
     ObjectInvalidOptionError,
     ObjectNotRegistered,
+    OverrideOptionError,
     ParamsFileNotExists,
     UnexpectedTypeOptionArguments,
 )
@@ -218,6 +219,9 @@ class Smart(Generic[T]):
             and self._params == other._params
         )
 
+    def __hash__(self) -> int:
+        return hash(strutil.join_keys(self._trace, repr(self)))
+
     def keys(
         self,
         flatten: bool = False,
@@ -782,7 +786,10 @@ class Smart(Generic[T]):
             )
 
         if name in self.register.origins:
-            name = self.register.origins[name]
+            name, registered_option = typeutil.parse_class_name(self.register.origins[name])
+            if registered_option and option:
+                raise OverrideOptionError(registered_option, option, trace)
+            option = registered_option
         elif self.allow_only_registered_classes:
             raise ObjectNotRegistered(name, trace)
 
@@ -879,19 +886,30 @@ class Smart(Generic[T]):
                     representation[name] = {
                         self.keyword: Smart.__name__,
                     }
-                elif get_origin(annotation) is Smart:
+                elif (origin := get_origin(annotation)) is Smart or origin is type:
                     param_type, *_ = get_args(annotation)
 
+                    if origin is Smart:
+                        value = Option.SMART.value
+                        argument_representation = self._object_representation(
+                            obj=param_type,
+                            skip_default=skip_default,
+                        )
+                    else:
+                        value = Option.TYPE.value
+                        argument_representation = {}
+
                     keyword = inspect.formatannotation(param_type)
-                    keyword = self.register.aliases.get(keyword, keyword)
-                    keyword = strutil.join_objects(keyword, Option.SMART.value)
+                    smart_keyword = strutil.join_objects(keyword, value)
+                    if smart_keyword in self.register.aliases:
+                        keyword = self.register.aliases[smart_keyword]
+                    else:
+                        keyword = self.register.aliases.get(keyword, keyword)
+                        keyword = strutil.join_objects(keyword, value)
 
                     representation[name] = {
                         self.keyword: keyword,
-                        **self._object_representation(
-                            obj=param_type,
-                            skip_default=skip_default,
-                        ),
+                        **argument_representation,
                     }
                 elif isinstance(default, (bool, float, int, str, type(None))):
                     representation[name] = default
