@@ -2,16 +2,22 @@ from enum import Enum
 from typing import Tuple, cast
 
 
-class Option(str, Enum):
-    SMART = 'Smart'
-    TYPE = 'Type'
-
-
-class Print(str, Enum):
-    PARAMS = 'params'
-    DICT = 'dict'
-    KEYS = 'keys'
+class StrEnum(str, Enum):
+    @classmethod
+    def keys(cls) -> Tuple[str, ...]:
+        return tuple(cast(Enum, item).name for item in cls)
 
     @classmethod
     def values(cls) -> Tuple[str, ...]:
         return tuple(cast(Enum, item).value for item in cls)
+
+
+class Option(StrEnum):
+    SMART = 'Smart'
+    TYPE = 'Type'
+
+
+class Print(StrEnum):
+    PARAMS = 'params'
+    DICT = 'dict'
+    KEYS = 'keys'
