@@ -1,14 +1,14 @@
 VOCABULARY = {
     'adjectives': [
-        'Aristotelian',
-        'Arthurian',
-        'Bohemian',
-        'Brethren',
-        'Mosaic',
-        'Oceanic',
-        'Proctor',
-        'Terran',
-        'Tudor',
+        'aristotelian',
+        'arthurian',
+        'bohemian',
+        'brethren',
+        'mosaic',
+        'oceanic',
+        'proctor',
+        'terran',
+        'tudor',
         'abroad',
         'absorbing',
         'abstract',
@@ -32,7 +32,6 @@ VOCABULARY = {
         'agreeable',
         'alienate',
         'aligned',
-        'all-round',
         'alleged',
         'almond',
         'alright',
@@ -85,7 +84,6 @@ VOCABULARY = {
         'beneficent',
         'besieged',
         'betting',
-        'big-money',
         'biggest',
         'biochemical',
         'bipolar',
@@ -96,7 +94,6 @@ VOCABULARY = {
         'bloat',
         'blocked',
         'blooded',
-        'blue-collar',
         'blushing',
         'boastful',
         'bolder',
@@ -236,7 +233,6 @@ VOCABULARY = {
         'doctrinal',
         'doing',
         'dotted',
-        'double-blind',
         'downbeat',
         'dozen',
         'draining',
@@ -279,7 +275,6 @@ VOCABULARY = {
         'esoteric',
         'essential',
         'evaporated',
-        'ever-present',
         'evergreen',
         'everlasting',
         'exacting',
@@ -298,12 +293,10 @@ VOCABULARY = {
         'facsimile',
         'fading',
         'fainter',
-        'faith-based',
         'fallacious',
         'faltering',
         'famous',
         'fancier',
-        'fast-growing',
         'fated',
         'favourable',
         'fearless',
@@ -333,7 +326,6 @@ VOCABULARY = {
         'forked',
         'formative',
         'formulaic',
-        'foul-mouthed',
         'fractional',
         'fragrant',
         'fraudulent',
@@ -361,7 +353,6 @@ VOCABULARY = {
         'glorified',
         'glorious',
         'goalless',
-        'gold-plated',
         'goody',
         'grammatical',
         'grande',
@@ -375,25 +366,16 @@ VOCABULARY = {
         'grudging',
         'guaranteed',
         'gusty',
-        'half-breed',
-        'hand-held',
         'handheld',
-        'hands-off',
-        'hard-pressed',
         'harlot',
         'healing',
         'healthier',
         'healthiest',
         'heart',
-        'heart-shaped',
         'heathen',
         'hedonistic',
         'heralded',
         'herbal',
-        'high-density',
-        'high-performance',
-        'high-res',
-        'high-yield',
         'hissy',
         'hitless',
         'holiness',
@@ -403,7 +385,6 @@ VOCABULARY = {
         'hopeless',
         'horrendous',
         'horrible',
-        'hot-button',
         'huddled',
         'human',
         'humbling',
@@ -424,8 +405,6 @@ VOCABULARY = {
         'impressionable',
         'improbable',
         'impulsive',
-        'in-between',
-        'in-flight',
         'inattentive',
         'inbound',
         'inbounds',
@@ -479,12 +458,10 @@ VOCABULARY = {
         'leather',
         'leathern',
         'leery',
-        'left-footed',
         'legible',
         'leisure',
         'lessening',
         'liberating',
-        'life-size',
         'lifted',
         'lightest',
         'limitless',
@@ -494,14 +471,8 @@ VOCABULARY = {
         'livid',
         'lobster',
         'locked',
-        'long-held',
-        'long-lasting',
-        'long-running',
-        'long-suffering',
         'loudest',
         'loveliest',
-        'low-budget',
-        'low-carb',
         'lowering',
         'lucid',
         'luckless',
@@ -533,8 +504,6 @@ VOCABULARY = {
         'midway',
         'mighty',
         'migrating',
-        'mind-blowing',
-        'mind-boggling',
         'minor',
         'mirrored',
         'misguided',
@@ -549,14 +518,12 @@ VOCABULARY = {
         'motley',
         'motorized',
         'mounted',
-        'multi-million',
         'multidisciplinary',
         'muscled',
         'muscular',
         'muted',
         'mysterious',
         'mythic',
-        'nail-biting',
         'natural',
         'nauseous',
         'negative',
@@ -566,7 +533,6 @@ VOCABULARY = {
         'newest',
         'night',
         'nitrous',
-        'no-fly',
         'noncommercial',
         'nonsense',
         'north',
@@ -575,16 +541,12 @@ VOCABULARY = {
         'offensive',
         'oldest',
         'oncoming',
-        'one-eyed',
-        'one-year',
         'onstage',
         'onward',
         'opaque',
-        'open-ended',
         'operating',
         'opportunist',
         'opposing',
-        'opt-in',
         'ordinate',
         'outdone',
         'outlaw',
@@ -636,7 +598,6 @@ VOCABULARY = {
         'possible',
         'postpartum',
         'prank',
-        'pre-emptive',
         'precocious',
         'predicted',
         'premium',
@@ -673,7 +634,6 @@ VOCABULARY = {
         'pulsed',
         'purgatory',
         'quick',
-        'rapid-fire',
         'raunchy',
         'razed',
         'reactive',
@@ -707,7 +667,6 @@ VOCABULARY = {
         'reversing',
         'revolving',
         'ridiculous',
-        'right-hand',
         'ringed',
         'risque',
         'robust',
@@ -715,7 +674,6 @@ VOCABULARY = {
         'rotating',
         'roused',
         'rubber',
-        'run-down',
         'running',
         'runtime',
         'rustling',
@@ -734,9 +692,7 @@ VOCABULARY = {
         'scratchy',
         'scrolled',
         'seated',
-        'second-best',
         'segregated',
-        'self-taught',
         'semiautomatic',
         'senior',
         'sensed',
@@ -752,7 +708,6 @@ VOCABULARY = {
         'shivering',
         'shoestring',
         'short',
-        'short-lived',
         'signed',
         'simplest',
         'simplistic',
@@ -775,7 +730,6 @@ VOCABULARY = {
         'smouldering',
         'snuff',
         'socialized',
-        'solid-state',
         'sometime',
         'sought',
         'spanking',
@@ -818,7 +772,6 @@ VOCABULARY = {
         'sunshine',
         'supernatural',
         'supervisory',
-        'supply-side',
         'surrogate',
         'suspended',
         'suspenseful',
@@ -845,7 +798,6 @@ VOCABULARY = {
         'theistic',
         'thicker',
         'threatening',
-        'tight-lipped',
         'timed',
         'timely',
         'timid',
@@ -863,7 +815,6 @@ VOCABULARY = {
         'trusting',
         'trying',
         'twisted',
-        'two-lane',
         'tyrannical',
         'unaided',
         'unassisted',
@@ -930,16 +881,12 @@ VOCABULARY = {
         'visceral',
         'visual',
         'voluptuous',
-        'walk-on',
         'wanton',
         'warlike',
         'washed',
         'waterproof',
         'waved',
         'weakest',
-        'well-bred',
-        'well-chosen',
-        'well-informed',
         'wetting',
         'wheeled',
         'whirlwind',
@@ -958,32 +905,31 @@ VOCABULARY = {
         'workable',
         'worldly',
         'worldwide',
-        'worst-case',
         'worsted',
         'worthless',
     ],
     'nouns': [
-        'Armour',
-        'Barrymore',
-        'Cabot',
-        'Catholicism',
-        'Chihuahua',
-        'Christianity',
-        'Easter',
-        'Frenchman',
-        'Lowry',
-        'Mayer',
-        'Orientalism',
-        'Pharaoh',
-        'Pueblo',
-        'Pullman',
-        'Rodeo',
-        'Saturday',
-        'Sister',
-        'Snead',
-        'Syrah',
-        'Tuesday',
-        'Woodward',
+        'armour',
+        'barrymore',
+        'cabot',
+        'catholicism',
+        'chihuahua',
+        'christianity',
+        'easter',
+        'frenchman',
+        'lowry',
+        'mayer',
+        'orientalism',
+        'pharaoh',
+        'pueblo',
+        'pullman',
+        'rodeo',
+        'saturday',
+        'sister',
+        'snead',
+        'syrah',
+        'tuesday',
+        'woodward',
         'abbey',
         'absence',
         'absorption',
@@ -1128,7 +1074,6 @@ VOCABULARY = {
         'bureaucracy',
         'burglary',
         'buyout',
-        'by-election',
         'cabal',
         'cabbage',
         'calamity',
@@ -1147,7 +1092,6 @@ VOCABULARY = {
         'certification',
         'charade',
         'chasm',
-        'check-in',
         'cheerleader',
         'cheesecake',
         'chemotherapy',
@@ -1221,7 +1165,6 @@ VOCABULARY = {
         'criminality',
         'crocodile',
         'cropping',
-        'cross-examination',
         'crossover',
         'crossroads',
         'culprit',
@@ -1507,7 +1450,6 @@ VOCABULARY = {
         'ligament',
         'lighting',
         'likeness',
-        'line-up',
         'lineage',
         'liner',
         'lineup',
@@ -1785,9 +1727,6 @@ VOCABULARY = {
         'seduction',
         'seeder',
         'seizure',
-        'self-confidence',
-        'self-control',
-        'self-respect',
         'semicolon',
         'semiconductor',
         'semifinal',
@@ -1888,7 +1827,6 @@ VOCABULARY = {
         'ticker',
         'tiger',
         'tights',
-        'to-day',
         'tossing',
         'touchdown',
         'tourist',
