@@ -12,6 +12,7 @@ from smartparams.exceptions import (
     ParamsFileNotExists,
     UnexpectedArgument,
 )
+from smartparams.utils.enums import Option
 from tests.custom_classes import (
     Class,
     ClassChild,
@@ -139,6 +140,7 @@ class TestSmartRepresentationCase(IntegrationCase):
     def test_object_representation__with_defaults(self) -> None:
         class_name = f"{Class.__module__}.{Class.__qualname__}"
         expected = {
+            'class_type': {'class': f'{class_name}:Type'},
             'vanilla_cls': {'class': class_name, 'arg1': 'str???', 'arg2': 5},
             'smart_cls': {'class': f'{class_name}:Smart', 'arg1': 'str???', 'arg2': 5},
             'smart': {'class': 'Smart'},
@@ -152,6 +154,7 @@ class TestSmartRepresentationCase(IntegrationCase):
     def test_object_representation__without_defaults(self) -> None:
         class_name = f"{Class.__module__}.{Class.__qualname__}"
         expected = {
+            'class_type': {'class': f'{class_name}:Type'},
             'vanilla_cls': {'class': class_name, 'arg1': 'str???'},
             'smart_cls': {'class': f'{class_name}:Smart', 'arg1': 'str???'},
             'smart': {'class': 'Smart'},
@@ -164,12 +167,18 @@ class TestSmartRepresentationCase(IntegrationCase):
 
     def test_object_representation__with_aliases(self) -> None:
         class_name = f"{Class.__module__}.{Class.__qualname__}"
+        class_name_smart = f"{class_name}:{Option.SMART.value}"
         class_child_name = f"{ClassChild.__module__}.{ClassChild.__qualname__}"
         self.smart.allow_only_registered_classes = True
-        self.smart.register({class_name: 'Parent', class_child_name: 'Child'})
+        self.smart.register(
+            (class_name, 'Parent'),
+            (class_child_name, 'Child'),
+            (class_name_smart, 'SmartParent'),
+        )
         expected = {
+            'class_type': {'class': 'Parent:Type'},
             'vanilla_cls': {'class': 'Parent', 'arg1': 'str???', 'arg2': 5},
-            'smart_cls': {'class': 'Parent:Smart', 'arg1': 'str???', 'arg2': 5},
+            'smart_cls': {'class': 'SmartParent', 'arg1': 'str???', 'arg2': 5},
             'smart': {'class': 'Smart'},
             'unknown': '???',
         }
