@@ -7,6 +7,7 @@ from smartparams.exceptions import (
     MissingArgument,
     ObjectInvalidOptionError,
     ObjectNotRegistered,
+    OverrideOptionError,
     UnexpectedTypeOptionArguments,
 )
 from smartparams.smart import Smart
@@ -45,6 +46,13 @@ class TestSmart(UnitCase):
     def test__not_callable(self) -> None:
         self.assertRaises(TypeError, Smart, 'not_callable')
 
+    def test__is_hashable(self) -> None:
+        smart: Smart = Smart(Class, a={10: 3})
+
+        smart_hash = hash(smart)
+
+        self.assertIsInstance(smart_hash, int)
+
 
 class TestSmartCallCase(UnitCase):
     def setUp(self) -> None:
@@ -383,7 +391,7 @@ class TestSmartInitCase(UnitCase):
 
     def test_init__with_aliases(self) -> None:
         self.smart.allow_only_registered_classes = True
-        self.smart.register({self.class_name: 'Class'})
+        self.smart.register((self.class_name, 'Class'))
         self.smart.set('object.class', 'Class')
 
         result = self.smart.init('object')
@@ -391,7 +399,7 @@ class TestSmartInitCase(UnitCase):
         self.assertIsInstance(result, Class)
 
     def test_init__with_aliases_not_used(self) -> None:
-        self.smart.register({self.class_name: 'Class'})
+        self.smart.register((self.class_name, 'Class'))
 
         result = self.smart.init('object')
 
@@ -399,6 +407,18 @@ class TestSmartInitCase(UnitCase):
 
     def test_init__with_aliases_error(self) -> None:
         self.smart.allow_only_registered_classes = True
-        self.smart.register({self.class_name: 'Class'})
+        self.smart.register((self.class_name, 'Class'))
 
         self.assertRaises(ObjectNotRegistered, self.smart.init, 'object')
+
+    def test_init__with_aliases_and_option(self) -> None:
+        self.smart.register((self.class_name + ':Smart', self.class_name))
+
+        result = self.smart.init('object')
+
+        self.assertIsInstance(result, Smart)
+
+    def test_init__with_aliases_and_option__overridden_options(self) -> None:
+        self.smart.register((self.class_name + ':Smart', self.class_name))
+
+        self.assertRaises(OverrideOptionError, self.smart.init, 'smart')
